@@ -268,7 +268,8 @@ class Microservices(BaseClass, ABC):
                 },
                 "data": data,
                 "headers": {
-                    "Asynchronous": False
+                    "Asynchronous": False,
+                    "Authorizacion": ""
                 }
             }, id_trans)
 
